@@ -1,6 +1,6 @@
 package App::GitGitr;
 our $AUTHORITY = 'cpan:GENEHACK';
-$App::GitGitr::VERSION = '0.905';
+$App::GitGitr::VERSION = '0.906';
 # ABSTRACT: GitGitr command support. See L<gitgitr> for full documentation.
 
 use parent 'App::Cmd::Simple';
@@ -93,12 +93,21 @@ sub _build_version {
 
 sub _download {
   my( $self , $opt , $version ) = @_;
+
   say "*** download" if $opt->{verbose};
+
   my $pkg_path = sprintf "git-%s.tar.gz" , $version;
+
   my $url = sprintf "https://kernel.org/pub/software/scm/git/%s" , $pkg_path;
   #my $url = sprintf "http://git-core.googlecode.com/files/%s" , $pkg_path;
-  my $ret = getstore( $url , $pkg_path );
-  die $ret unless $ret eq '200';
+
+  my $response = HTTP::Tiny->new->mirror( $url , $pkg_path );
+  unless ( $response->{success} ) {
+    my $message = sprintf "DOWNLOAD FAILED!\n** STATUS: %s REASON: %s",
+      $response->{status}, $response->{reason};
+    croak $message;
+  }
+
   return $pkg_path;
 };
 
@@ -174,7 +183,7 @@ App::GitGitr - GitGitr command support. See L<gitgitr> for full documentation.
 
 =head1 VERSION
 
-version 0.905
+version 0.906
 
 =head1 AUTHOR
 
